@@ -20,16 +20,16 @@
 */
 
 #include "formatter.h"
-#include "ktnefparser.h"
-#include "ktnefmessage.h"
 #include "ktnefdefs.h"
+#include "ktnefmessage.h"
+#include "ktnefparser.h"
 
 #include <kcontacts/phonenumber.h>
 #include <kcontacts/vcardconverter.h>
 
+#include <KCalUtils/IncidenceFormatter>
 #include <KCalendarCore/Calendar>
 #include <KCalendarCore/ICalFormat>
-#include <KCalUtils/IncidenceFormatter>
 
 #include <KLocalizedString>
 
@@ -47,14 +47,12 @@ using namespace KTnef;
 
 //-----------------------------------------------------------------------------
 //@cond IGNORE
-static QString stringProp(KTNEFMessage *tnefMsg, quint32 key,
-                          const QString &fallback = QString())
+static QString stringProp(KTNEFMessage *tnefMsg, quint32 key, const QString &fallback = QString())
 {
     return tnefMsg->findProp(key < 0x10000 ? key & 0xFFFF : key >> 16, fallback);
 }
 
-static QString sNamedProp(KTNEFMessage *tnefMsg, const QString &name,
-                          const QString &fallback = QString())
+static QString sNamedProp(KTNEFMessage *tnefMsg, const QString &name, const QString &fallback = QString())
 {
     return tnefMsg->findNamedProp(name, fallback);
 }
@@ -77,8 +75,8 @@ static QDateTime pureISOToLocalQDateTime(const QString &dtStr)
 
         // correct for GMT ( == Zulu time == UTC )
         if (dtStr.at(dtStr.length() - 1) == QLatin1Char('Z')) {
-            //dT = dT.addSecs( 60 * KRFCDate::localUTCOffset() );
-            //localUTCOffset( dT ) );
+            // dT = dT.addSecs( 60 * KRFCDate::localUTCOffset() );
+            // localUTCOffset( dT ) );
             dT = dT.toLocalTime();
         }
         return dT;
@@ -100,7 +98,7 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
 
     if (parser.openDevice(&buf)) {
         KTNEFMessage *tnefMsg = parser.message();
-        //QMap<int,KTNEFProperty*> props = parser.message()->properties();
+        // QMap<int,KTNEFProperty*> props = parser.message()->properties();
 
         // Everything depends from property PR_MESSAGE_CLASS
         // (this is added by KTNEFParser):
@@ -139,14 +137,13 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                 prodID += QLatin1String("VERSION:2.0\n");
                 calFormat.setApplication(QStringLiteral("Outlook"), prodID);
 
-                //iTIPMethod method;
+                // iTIPMethod method;
                 if (bCompatMethodRequest) {
-                    //method = iTIPRequest;
+                    // method = iTIPRequest;
                 } else if (bCompatMethodCancled) {
-                    //method = iTIPCancel;
-                } else if (bCompatMethodAccepted || bCompatMethodAcceptedCond ||
-                           bCompatMethodDeclined) {
-                    //method = iTIPReply;
+                    // method = iTIPCancel;
+                } else if (bCompatMethodAccepted || bCompatMethodAcceptedCond || bCompatMethodDeclined) {
+                    // method = iTIPReply;
                     bIsReply = true;
                 } else {
                     // pending(khz): verify whether "0x0c17" is the right tag ???
@@ -160,11 +157,11 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                     if (tnefMsg->findProp(0x0c17) == QLatin1Char('1')) {
                         bIsReply = true;
                     }
-                    //method = iTIPRequest;
+                    // method = iTIPRequest;
                 }
 
                 /// ###  FIXME Need to get this attribute written
-                //ScheduleMessage schedMsg( event, method, ScheduleMessage::Unknown );
+                // ScheduleMessage schedMsg( event, method, ScheduleMessage::Unknown );
 
                 QString sSenderSearchKeyEmail(tnefMsg->findProp(0x0C1D));
                 if (sSenderSearchKeyEmail.isEmpty()) {
@@ -229,7 +226,7 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                         event->addAttendee(attendee);
                     }
                 }
-                s = tnefMsg->findProp(0x3ff8);   // look for organizer property
+                s = tnefMsg->findProp(0x3ff8); // look for organizer property
                 if (s.isEmpty() && !bIsReply) {
                     s = sSenderSearchKeyEmail;
                 }
@@ -242,11 +239,10 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                 if (!dt.isValid()) {
                     dt = tnefMsg->property(0x0060).toDateTime();
                 }
-                event->setDtStart(dt);     // ## Format??
+                event->setDtStart(dt); // ## Format??
 
                 dt = tnefMsg->property(0x819c).toDateTime();
-                if (!dt.isValid())
-                {
+                if (!dt.isValid()) {
                     dt = tnefMsg->property(0x0061).toDateTime();
                 }
                 event->setDtEnd(dt);
@@ -254,8 +250,8 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                 s = tnefMsg->findProp(0x810d);
                 event->setLocation(s);
                 // is it OK to set this to OPAQUE always ??
-                //vPart += "TRANSP:OPAQUE\n"; ###FIXME, portme!
-                //vPart += "SEQUENCE:0\n";
+                // vPart += "TRANSP:OPAQUE\n"; ###FIXME, portme!
+                // vPart += "SEQUENCE:0\n";
 
                 // is "0x0023" OK  -  or should we look for "0x0003" ??
                 s = tnefMsg->findProp(0x0062);
@@ -287,13 +283,9 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                 event->setPriority(s.toInt());
                 // is reminder flag set ?
                 if (!tnefMsg->findProp(0x8503).isEmpty()) {
-                    Alarm::Ptr alarm(new Alarm(event.data()));     // TODO: fix when KCalendarCore::Alarm is fixed
-                    QDateTime highNoonTime =
-                        pureISOToLocalQDateTime(tnefMsg->findProp(0x8502).
-                                                remove(QLatin1Char('-')).remove(QLatin1Char(':')));
-                    QDateTime wakeMeUpTime =
-                        pureISOToLocalQDateTime(tnefMsg->findProp(0x8560, QString()).
-                                                remove(QLatin1Char('-')).remove(QLatin1Char(':')));
+                    Alarm::Ptr alarm(new Alarm(event.data())); // TODO: fix when KCalendarCore::Alarm is fixed
+                    QDateTime highNoonTime = pureISOToLocalQDateTime(tnefMsg->findProp(0x8502).remove(QLatin1Char('-')).remove(QLatin1Char(':')));
+                    QDateTime wakeMeUpTime = pureISOToLocalQDateTime(tnefMsg->findProp(0x8560, QString()).remove(QLatin1Char('-')).remove(QLatin1Char(':')));
                     alarm->setTime(wakeMeUpTime);
 
                     if (highNoonTime.isValid() && wakeMeUpTime.isValid()) {
@@ -308,12 +300,12 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                     //        so we always set 'DISPLAY' (no sounds, no images...)
                     event->addAlarm(alarm);
                 }
-                //ensure we have a uid for this event
+                // ensure we have a uid for this event
                 if (event->uid().isEmpty()) {
                     event->setUid(CalFormat::createUniqueId());
                 }
                 cal->addEvent(event);
-                //bOk = true;
+                // bOk = true;
                 // we finished composing a vCal
             } else if (bCompatClassNote || QLatin1String("IPM.CONTACT") == msgClass) {
                 addressee.setUid(stringProp(tnefMsg, attMSGID));
@@ -321,23 +313,17 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                 addressee.insertEmail(sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_EMAIL1EMAILADDRESS)), true);
                 addressee.insertEmail(sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_EMAIL2EMAILADDRESS)), false);
                 addressee.insertEmail(sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_EMAIL3EMAILADDRESS)), false);
-                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-IMAddress"),
+                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"),
+                                       QStringLiteral("X-IMAddress"),
                                        sNamedProp(tnefMsg, QStringLiteral(MAPI_TAG_CONTACT_IMADDRESS)));
-                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-SpousesName"),
-                                       stringProp(tnefMsg, MAPI_TAG_PR_SPOUSE_NAME));
-                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-ManagersName"),
-                                       stringProp(tnefMsg, MAPI_TAG_PR_MANAGER_NAME));
-                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-AssistantsName"),
-                                       stringProp(tnefMsg, MAPI_TAG_PR_ASSISTANT));
-                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Department"),
-                                       stringProp(tnefMsg, MAPI_TAG_PR_DEPARTMENT_NAME));
-                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Office"),
-                                       stringProp(tnefMsg, MAPI_TAG_PR_OFFICE_LOCATION));
-                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Profession"),
-                                       stringProp(tnefMsg, MAPI_TAG_PR_PROFESSION));
+                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-SpousesName"), stringProp(tnefMsg, MAPI_TAG_PR_SPOUSE_NAME));
+                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-ManagersName"), stringProp(tnefMsg, MAPI_TAG_PR_MANAGER_NAME));
+                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-AssistantsName"), stringProp(tnefMsg, MAPI_TAG_PR_ASSISTANT));
+                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Department"), stringProp(tnefMsg, MAPI_TAG_PR_DEPARTMENT_NAME));
+                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Office"), stringProp(tnefMsg, MAPI_TAG_PR_OFFICE_LOCATION));
+                addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Profession"), stringProp(tnefMsg, MAPI_TAG_PR_PROFESSION));
 
-                QString s = tnefMsg->findProp(MAPI_TAG_PR_WEDDING_ANNIVERSARY).
-                            remove(QLatin1Char('-')).remove(QLatin1Char(':'));
+                QString s = tnefMsg->findProp(MAPI_TAG_PR_WEDDING_ANNIVERSARY).remove(QLatin1Char('-')).remove(QLatin1Char(':'));
                 if (!s.isEmpty()) {
                     addressee.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Anniversary"), s);
                 }
@@ -398,30 +384,23 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
 
                 QString nr;
                 nr = stringProp(tnefMsg, MAPI_TAG_PR_HOME_TELEPHONE_NUMBER);
-                addressee.insertPhoneNumber(
-                    KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Home));
+                addressee.insertPhoneNumber(KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Home));
                 nr = stringProp(tnefMsg, MAPI_TAG_PR_BUSINESS_TELEPHONE_NUMBER);
-                addressee.insertPhoneNumber(
-                    KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Work));
+                addressee.insertPhoneNumber(KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Work));
                 nr = stringProp(tnefMsg, MAPI_TAG_PR_MOBILE_TELEPHONE_NUMBER);
-                addressee.insertPhoneNumber(
-                    KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Cell));
+                addressee.insertPhoneNumber(KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Cell));
                 nr = stringProp(tnefMsg, MAPI_TAG_PR_HOME_FAX_NUMBER);
-                addressee.insertPhoneNumber(
-                    KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Fax | KContacts::PhoneNumber::Home));
+                addressee.insertPhoneNumber(KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Fax | KContacts::PhoneNumber::Home));
                 nr = stringProp(tnefMsg, MAPI_TAG_PR_BUSINESS_FAX_NUMBER);
-                addressee.insertPhoneNumber(
-                    KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Fax | KContacts::PhoneNumber::Work));
+                addressee.insertPhoneNumber(KContacts::PhoneNumber(nr, KContacts::PhoneNumber::Fax | KContacts::PhoneNumber::Work));
 
-                s = tnefMsg->findProp(MAPI_TAG_PR_BIRTHDAY).
-                    remove(QLatin1Char('-')).remove(QLatin1Char(':'));
+                s = tnefMsg->findProp(MAPI_TAG_PR_BIRTHDAY).remove(QLatin1Char('-')).remove(QLatin1Char(':'));
                 if (!s.isEmpty()) {
                     addressee.setBirthday(QDateTime::fromString(s));
                 }
 
-                //bOk = (!addressee.isEmpty());
+                // bOk = (!addressee.isEmpty());
             } else if (QLatin1String("IPM.NOTE") == msgClass) {
-
             } // else if ... and so on ...
         }
     }
@@ -438,9 +417,7 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
     return QString::fromUtf8(converter.createVCard(addressee));
 }
 
-QString KTnef::formatTNEFInvitation(const QByteArray &tnef,
-                                    const MemoryCalendar::Ptr &cal,
-                                    KCalUtils::InvitationFormatterHelper *h)
+QString KTnef::formatTNEFInvitation(const QByteArray &tnef, const MemoryCalendar::Ptr &cal, KCalUtils::InvitationFormatterHelper *h)
 {
     const QString vPart = msTNEFToVPart(tnef);
     QString iCal = KCalUtils::IncidenceFormatter::formatICalInvitation(vPart, cal, h);
